import os

import jinja2
import yaml

from docker_recipe.cli import parser
from docker_recipe.data_structure import DockerRecipe
from docker_recipe.filters import filter_basename, filter_dirname


def load_recipe(path: str) -> DockerRecipe:
    with open(path) as f_recipe:
        config_contents = f_recipe.read()

    return DockerRecipe(**yaml.load(config_contents, Loader=yaml.FullLoader))


def render_file(path: str, recipe: DockerRecipe) -> str:
    fsl = jinja2.FileSystemLoader(os.path.dirname(path))
    env = jinja2.Environment(loader=fsl)
    env.filters['basename'] = filter_basename
    env.filters['dirname'] = filter_dirname
    tpl = env.get_template(os.path.basename(path))
    output = tpl.render({"recipe": recipe})

    return output if output.endswith("\n") else output + "\n"


def main():
    args = parser.parse_args()

    with open(args.gitlab_ci_output_file, 'w+') as f_gitlab_ci:
        f_gitlab_ci.write(render_file(args.gitlab_ci_template,
                                      load_recipe(args.docker_recipe)))


if __name__ == '__main__':
    main()



import argparse
import os

parser = argparse.ArgumentParser(description="Docker Recipe File")
parser.add_argument('-r',
                    '--docker-recipe',
                    default=os.path.join(os.getcwd(), 'docker-recipe.yml'),
                    help='Path to the docker-recipe.yml file. ' +
                         'Default is `docker-recipe.yml` in the current working directory.')

parser.add_argument('-g',
                    '--gitlab-ci-template',
                    default=os.path.join(os.getcwd(), '.gitlab-ci.recipe.yml'),
                    help='Path to the .gitlab-ci.recipe.yml file. ' +
                         'Default is `.gitlab-ci.recipe.yml` in the current working directory.')

parser.add_argument('-o',
                    '--gitlab-ci-output-file',
                    default=os.path.join(os.getcwd(), '.gitlab-ci.yml'),
                    help='Path to the .gitlab-ci.yml file. ' +
                         'Default is `.gitlab-ci.recipe.yml` in the current working directory.')



import typing
import pydantic


class DockerRecipeImage(pydantic.BaseModel):
    name: str
    Dockerfile: str
    arguments: typing.Dict[str, str] = {}
    depends_on: typing.List[str] = []
    extra_tags: typing.List[str] = []


class DockerRecipe(pydantic.BaseModel):
    images: typing.List[DockerRecipeImage]



from setuptools import setup, find_packages

setup(
    name="docker-recipe",
    version="1.0.0",
    packages=find_packages(),
    install_requires=[
        'pydantic~=1.10.8',
        'PyYaml~=6.0',
        'Jinja2~=3.1.2',
    ],
    author="Stephan Meijer",
    author_email="me@stephanmeijer.com",
    description="A way to cook multiple Dockerfiles",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/stephanmeijer/docker-recipe",
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
    ],
    entry_points={
        'console_scripts': [
            'docker-recipe=docker_recipe:main',  # map the docker-recipe command to a function
        ],
    },
)
